﻿Imports ThinkGeo.MapSuite.Core
Imports ThinkGeo.MapSuite.DesktopEdition
Imports System.Collections.ObjectModel
Imports System.Drawing.Printing
Imports System.IO
Imports System.ComponentModel
Imports System.Runtime.Serialization.Formatters.Binary

Public Class Form1
   Private moShapefile As ShapeFileFeatureLayer
   Private moFeatureExtent As RectangleShape
   Private moStyle1 As AreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Blue, GeoColor.SimpleColors.Black, 6)
   Private moStyle2 As AreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Red, GeoColor.SimpleColors.Black, 6)
   Private mbStyle1 As Boolean = True
   Public Enum EnumPagePosition
      TopLeft = 1
      TopRight = 2
      LowerLeft = 3
      LowerRight = 4
   End Enum
   Public Enum EnumCenterType
      Horizontal = 1
      Vertical = 2
   End Enum

   Private Sub Form1_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load

      CreateDefaultLayout()


      Dim sInstructions As String =
         "1. Click the 'Print' button to print the page layout." & ControlChars.CrLf & ControlChars.CrLf &
         "2. Note that the legend and the map features render poorly on the printer, the scaleline and scalebar look good." & ControlChars.CrLf & ControlChars.CrLf

      TextBox1.Text = sInstructions

   End Sub

   Public Sub CreateDefaultLayout()
      Dim oExtentRectangle As RectangleShape
      Dim moPrinterOverlay As PrinterInteractiveOverLay
      Dim moPrinterPage As PagePrinterLayer

      moPrinterOverlay = New PrinterInteractiveOverLay()
      With PageLayout
         '***** Setup the map unit, you want to always use feet or meters for printer layout maps
         .MapUnit = GeographyUnit.Feet
         '***** Create the default zoom levels for the layout map
         .ZoomLevelSet = New PrinterZoomLevelSet(.MapUnit, PrinterHelper.GetPointsPerGeographyUnit(.MapUnit))

         '***** Set the background color to gray so there is contrast with the white page
         .BackgroundOverlay.BackgroundBrush = New GeoSolidBrush(GeoColor.StandardColors.LightGray)

         '***** Create the PrinterInteractiveOverlay to contain all of the PrinterLayers.
         '***** The interactive overlay allows the layers to be interacted with
         .InteractiveOverlays.Add("PrinterOverlay", moPrinterOverlay)
         .InteractiveOverlays.MoveToBottom("PrinterOverlay")

         '***** Create the PagePrinterLayer which shows the page boundary and 
         '***** is the area the user will arrange all of the other layers on top of.
         moPrinterPage = New PagePrinterLayer()
         With moPrinterPage
            .Open()
            .BackgroundMask = AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.White, GeoColor.SimpleColors.Black, 1)
            moPrinterOverlay.PrinterLayers.Add("PrinterPage", moPrinterPage)
            '***** Get the page's extent, scale it up by 10%
            oExtentRectangle = CType(RectangleShape.ScaleUp(.GetPosition(), 10), RectangleShape)
            '***** Set oExtentRectangle as the default current extent
         End With
         .CurrentExtent = oExtentRectangle

         '***** Set the minimum scale of the map to the last zoom level
         .MinimumScale = .ZoomLevelSet.ZoomLevel20.Scale

         '***** Add a container for the map layers
         AddMapLayerContainer(mGetPageLayoutMap)

         '***** Add a layer to the page layout
         AddMapLayer(mGetPageLayoutMap)

         '***** Add a scale line
         CreateDefaultScaleLine(mGetPageLayoutMap)

         '***** Add a scale bar
         CreateDefaultScaleBar(mGetPageLayoutMap)

         '***** A refresh is done in the form's Shown event
         AddLegend()
         AddImage()
      End With
   End Sub
   Public Sub AddImage()
      Dim sPath As String = "..\..\Data\Steve.jpg"
      Dim moPrinterOverlay As PrinterInteractiveOverLay = mGetPrinterOverlay()
      Dim oImage As New GeoImage(sPath)
      Dim oImageLayer As New ImagePrinterLayer(oImage)

      oImageLayer.SetPosition(1, 1, -2, -2, PrintingUnit.Inch)
      With oImageLayer
         .DragMode = PrinterDragMode.Draggable
         .ResizeMode = PrinterResizeMode.MaintainAspectRatio
         .Unit = PrintingUnit.Inch
      End With
      moPrinterOverlay.PrinterLayers.Add(oImageLayer)
   End Sub
   Public Sub AddLegend()
      'Dim oLegend As New LegendPrinterLayer()
      'Dim oLegendItem As LegendItem
      'Dim oTextStyle As TextStyle

      'oTextStyle = TextStyles.CreateSimpleTextStyle("Bogus Map Legend", "Arial", 12, DrawingFontStyles.Regular, GeoColor.SimpleColors.Black)
      'oLegendItem = New LegendItem(100, 20, 10, 10, AreaStyles.Country1, oTextStyle)

      'oLegend.Title = oLegendItem


      'oTextStyle = TextStyles.CreateSimpleTextStyle("Polygon Layer", "Arial", 10, DrawingFontStyles.Regular, GeoColor.SimpleColors.Black)
      'oLegendItem = New LegendItem(100, 20, 10, 10, AreaStyles.Country1, oTextStyle)

      'oLegend.LegendItems.Add(oLegendItem)

      'With oLegend
      '   .SetPosition(2, 1, New PointShape(0, 0), PrintingUnit.Inch)
      '   '.Height = 200
      '   '.Width = 200
      '   .BackgroundMask = AreaStyles.Antarctica1
      'End With
      Dim moPrinterOverlay As PrinterInteractiveOverLay = mGetPrinterOverlay()
      'moPrinterOverlay.PrinterLayers.Add("Legend", oLegend)

      '****************************************

      ' Create a legend item for the title.
      Dim title As New LegendItem()
      title.TextStyle = New TextStyle("Map Legend",
                                      New GeoFont("Arial", 10, DrawingFontStyles.Bold),
                                      New GeoSolidBrush(GeoColor.SimpleColors.Black))
      title.Width = 300
      ' Create a legend item for the state borders.  This example uses a modified LineStyle.
      Dim legendItem1 As New LegendItem()
      Dim stateBorderStyle As New LineStyle()
      stateBorderStyle.OuterPen.DashStyle = LineDashStyle.Dash
      stateBorderStyle.OuterPen.Width = 2
      stateBorderStyle.OuterPen.Color = GeoColor.FromArgb(255, 156, 155, 154)
      legendItem1.ImageStyle = stateBorderStyle
      legendItem1.TextStyle = New TextStyle("State Borders XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX", New GeoFont("Arial", 8), New GeoSolidBrush(GeoColor.SimpleColors.Black))
      legendItem1.Width = 300

      ' Create a legend item for the state borders.  This example uses a simple AreaStyle.
      Dim legendItem2 As New LegendItem()
      legendItem2.ImageStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 167, 204, 149))
      legendItem2.TextStyle = New TextStyle("Forests", New GeoFont("Arial", 8), New GeoSolidBrush(GeoColor.SimpleColors.Black))
      legendItem2.Width = 300

      ' Create A legend item for the airports.  This example uses a .png file.
      Dim legendItem3 As New LegendItem()
      'legendItem3.ImageStyle = new PointStyle(new GeoImage(@"..\..\Resources\airport_small_size3.png"))
      legendItem3.TextStyle = New TextStyle("Airports", New GeoFont("Arial", 8), New GeoSolidBrush(GeoColor.SimpleColors.Black))
      legendItem3.Width = 300

      ' Create the LegendAdornmentLayer and add the LegendItems.
      Dim legendLayer As New LegendPrinterLayer()
      legendLayer.BackgroundMask = AreaStyles.CreateLinearGradientStyle(New GeoColor(255, 255, 255, 255), New GeoColor(255, 230, 230, 230), 90, GeoColor.SimpleColors.Black)

      legendLayer.LegendItems.Add(legendItem1)
      legendLayer.LegendItems.Add(legendItem2)
      legendLayer.LegendItems.Add(legendItem3)

      legendLayer.Height = 100
      legendLayer.Width = 200

      legendLayer.Title = title
      '***************************

      moPrinterOverlay = mGetPrinterOverlay()
      moPrinterOverlay.PrinterLayers.Add("Legend", legendLayer)

      legendLayer.ResizeMode = PrinterResizeMode.Resizable
      legendLayer.SetPosition(200 / 96, 100 / 96, New PointShape(-2, 3.5), PrintingUnit.Inch)


   End Sub
   Public Sub AddMapLayer(moPageLayoutMap As MapPrinterLayer)

      moPageLayoutMap.MapUnit = GeographyUnit.Meter

      Dim sPath As String = "..\..\Data\NewPoly.shp"
      moShapefile = New ShapeFileFeatureLayer(sPath, ShapeFileReadWriteMode.ReadWrite)
      moPageLayoutMap.Layers.Add(moShapefile)
      moShapefile.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Yellow, GeoColor.SimpleColors.Black, 1)
      moShapefile.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20

      moShapefile.Open()
      Dim oFeature As Feature = moShapefile.QueryTools.GetFeatureById("3", ReturningColumnsType.AllColumns)


      moFeatureExtent = moShapefile.GetBoundingBox
      moFeatureExtent.ScaleUp(100)
      moPageLayoutMap.MapExtent = moShapefile.GetBoundingBox


   End Sub

   Public Sub SetScale(moPageLayoutMap As MapPrinterLayer)
      Dim dWidth As Single = CSng(moPageLayoutMap.GetPosition(PrintingUnit.Inch).Width * 96)
      Dim dHeight As Single = CSng(moPageLayoutMap.GetPosition(PrintingUnit.Inch).Height * 96)
      Dim oExtent As RectangleShape = ExtentHelper.ZoomToScale(15840, moPageLayoutMap.MapExtent, moPageLayoutMap.MapUnit, dWidth, dHeight)
      oExtent = ExtentHelper.CenterAt(oExtent, moPageLayoutMap.MapExtent.GetCenterPoint, dWidth, dHeight)
      moPageLayoutMap.MapExtent = oExtent
      btnRefresh_Click(Nothing, Nothing)
   End Sub
   Public Sub AddMapLayerContainer(moPageLayoutMap As MapPrinterLayer)
      Dim oPageBoundingbox As RectangleShape = GetPageBoundingBox(PrintingUnit.Inch)

      moPageLayoutMap = New CustomPageLayoutMap()

      moPageLayoutMap.MapUnit = GeographyUnit.Feet

      '***** Create the MapPrinterLayer and set the position
      moPageLayoutMap.BackgroundMask = AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.White, GeoColor.SimpleColors.Black, 1)

      '***** Set the maps position slightly below the pages center and 7.5 inches wide and 9 inches tall
      oPageBoundingbox = GetPageBoundingBox(PrintingUnit.Inch)
      moPageLayoutMap.SetPosition(7.5, 9, oPageBoundingbox.GetCenterPoint().X, oPageBoundingbox.GetCenterPoint().Y - 0.25, PrintingUnit.Inch)

      '***** Add the MapPrinterLayer to the PrinterInteractiveOverlay
      Dim moPrinterOverlay As PrinterInteractiveOverLay = mGetPrinterOverlay()
      moPrinterOverlay.PrinterLayers.Add("MapPrinterLayer", moPageLayoutMap)
   End Sub
   Private Function GetPageBoundingBox(ByVal unit As PrintingUnit) As RectangleShape
      Dim moPrinterPage As PagePrinterLayer = mGetPrinterPage()
      Return moPrinterPage.GetPosition(unit)
   End Function
   Public Sub CreateDefaultScaleLine(moPageLayoutMap As MapPrinterLayer)
      Dim moPrinterOverlay As PrinterInteractiveOverLay = mGetPrinterOverlay()
      If moPrinterOverlay.PrinterLayers.Contains("ScaleLine") Then
         moPrinterOverlay.PrinterLayers.Remove("ScaleLine")
      End If
      Dim moScaleLineLayer As ScaleLinePrinterLayer
      '***** Create the scaleLinePrinterLayer and pass in the MapPrinterLayer
      moScaleLineLayer = New ScaleLinePrinterLayer(moPageLayoutMap)

      moScaleLineLayer.MapUnit = moPageLayoutMap.MapUnit

      moScaleLineLayer.Open()
      mSetPosition(2.5, 0.25, moScaleLineLayer, EnumPagePosition.LowerLeft, mGetPageLayoutMap)

      '***** Add the ScaleLinePrinterLayer to the PrinterInteractiveOverlay
      moPrinterOverlay.PrinterLayers.Add("ScaleLine", moScaleLineLayer)
   End Sub
   Public Sub CreateDefaultScaleBar(moPageLayoutMap As MapPrinterLayer)
      Dim moPrinterOverlay As PrinterInteractiveOverLay = mGetPrinterOverlay()
      If moPrinterOverlay.PrinterLayers.Contains("ScaleBar") Then
         moPrinterOverlay.PrinterLayers.Remove("ScaleBar")
      End If

      '***** Create the scaleLinePrinterLayer and pass in the MapPrinterLayer
      Dim moScaleBarLayer As ScaleBarPrinterLayer
      moScaleBarLayer = New ScaleBarPrinterLayer(moPageLayoutMap)

      With moScaleBarLayer
         .MapUnit = moPageLayoutMap.MapUnit
         .AlternateBarBrush = New GeoSolidBrush(GeoColor.SimpleColors.Black)
         .TextColor = GeoColor.SimpleColors.Black
         .Font = New GeoFont("Arial", 10)
         .BarBrush = New GeoSolidBrush(GeoColor.SimpleColors.BrightOrange)
         .UnitFamily = UnitSystem.Imperial
         .MaxWidth = 7
      End With

      moScaleBarLayer.Open()
      mSetPosition(2.5, 0.25, moScaleBarLayer, EnumPagePosition.LowerRight, mGetPageLayoutMap)

      '***** Add the ScaleLinePrinterLayer to the PrinterInteractiveOverlay
      moPrinterOverlay.PrinterLayers.Add("ScaleBar", moScaleBarLayer)
   End Sub
   Public Sub mSetPosition(ByVal dWidth As Double, ByVal dHeight As Double, ByVal oPrinterLayer As PrinterLayer, ByVal eInitialPosition As EnumPagePosition, moPageLayoutMap As MapPrinterLayer)
      Dim dCenterPointX As Double
      Dim dCenterPointY As Double
      Dim dDistanceFromEdge As Double = 0.25

      '***** Get the bounding box for the MapPrinterLayer
      moPageLayoutMap.Open()
      Dim oMapBoundingBox As RectangleShape = moPageLayoutMap.GetPosition(PrintingUnit.Inch)
      Select Case eInitialPosition
         Case EnumPagePosition.LowerRight
            dCenterPointX = oMapBoundingBox.LowerRightPoint.X - (dWidth / 2) - dDistanceFromEdge
            dCenterPointY = oMapBoundingBox.LowerRightPoint.Y + (dHeight / 2) + dDistanceFromEdge
         Case EnumPagePosition.LowerLeft
            dCenterPointX = oMapBoundingBox.LowerLeftPoint.X + (dWidth / 2) + dDistanceFromEdge
            dCenterPointY = oMapBoundingBox.LowerLeftPoint.Y + (dHeight / 2) + dDistanceFromEdge
         Case EnumPagePosition.TopRight
            dCenterPointX = oMapBoundingBox.UpperRightPoint.X - (dWidth / 2) - dDistanceFromEdge
            dCenterPointY = oMapBoundingBox.UpperRightPoint.Y - (dHeight / 2) - dDistanceFromEdge
         Case EnumPagePosition.TopLeft
            dCenterPointX = oMapBoundingBox.UpperLeftPoint.X + (dWidth / 2) + dDistanceFromEdge
            dCenterPointY = oMapBoundingBox.UpperLeftPoint.Y - (dHeight / 2) - dDistanceFromEdge
      End Select

      '***** Now let's try to place this layer in the lower right corner of the page
      oPrinterLayer.SetPosition(dWidth, dHeight, dCenterPointX, dCenterPointY, PrintingUnit.Inch)
   End Sub

   Private Sub btnRefresh_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnRefresh.Click
      mRefreshMapLayers(mGetPageLayoutMap)
   End Sub

   Private Sub mRefreshMapLayers(moPageLayoutMap As MapPrinterLayer)
      If Not moPageLayoutMap Is Nothing Then
         moPageLayoutMap.IsDrawing = True
         ''moPageLayoutMap.ClearCache()
      End If

      PageLayout.Refresh()

      If Not moPageLayoutMap Is Nothing Then
         moPageLayoutMap.IsDrawing = False
      End If
   End Sub
   Private Sub mCenterElement(ByVal eCenterType As EnumCenterType, ByVal oPrinterLayer As PrinterLayer)
      Dim oCurPosition As RectangleShape = Nothing
      Dim oNewCenterPoint As PointShape

      oPrinterLayer.Open()
      oCurPosition = oPrinterLayer.GetPosition(PrintingUnit.Inch)

      Dim oPageBoundingBox As RectangleShape = GetPageBoundingBox(PrintingUnit.Inch)


      If eCenterType = EnumCenterType.Horizontal Then
         oNewCenterPoint = New PointShape(0, oCurPosition.GetCenterPoint.Y)
      Else
         oNewCenterPoint = New PointShape(oCurPosition.GetCenterPoint.X, 0)
      End If

      oPrinterLayer.SetPosition(oCurPosition.Width, oCurPosition.Height, oNewCenterPoint, PrintingUnit.Inch)


      mRefreshMapLayers(mGetPageLayoutMap)
   End Sub


   Private Sub btnChangeStyle_Click(sender As Object, e As System.EventArgs) Handles btnChangeStyle.Click
      mbStyle1 = Not mbStyle1

      If mbStyle1 Then
         moShapefile.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = moStyle1
         moShapefile.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20
      Else
         moShapefile.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = moStyle2
         moShapefile.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20
      End If
      mRefreshMapLayers(mGetPageLayoutMap)
   End Sub

   Private Sub Form1_Shown(sender As Object, e As System.EventArgs) Handles Me.Shown
      'btnRefresh_Click(Nothing, Nothing)
      Me.PageLayout.Refresh()

   End Sub

   Public Function GetUserFolder() As String
      Dim sBasePath As String
      Dim sApplicationPath As String

      sBasePath = Environment.GetFolderPath(Environment.SpecialFolder.ApplicationData)
      sApplicationPath = Application.CompanyName & "\" & Application.ProductName & "\"

      If Not System.IO.Directory.Exists(sBasePath & "\" & sApplicationPath) Then
         System.IO.Directory.CreateDirectory(sBasePath & "\" & sApplicationPath)
      End If

      Return sBasePath & "\" & sApplicationPath

   End Function
   Private Function mGetPrinterOverlay() As PrinterInteractiveOverLay
      For Each oPrinterOverlay In PageLayout.InteractiveOverlays
         If TypeOf oPrinterOverlay Is PrinterInteractiveOverLay Then
            Return CType(oPrinterOverlay, PrinterInteractiveOverLay)
         End If
      Next oPrinterOverlay
      Return Nothing
   End Function
   Private Function mGetPageLayoutMap() As CustomPageLayoutMap
      Dim oPrinterOverlay As PrinterInteractiveOverLay = mGetPrinterOverlay()
      Dim oPrinterLayer As PrinterLayer
      For Each oPrinterLayer In oPrinterOverlay.PrinterLayers
         If TypeOf oPrinterLayer Is MapPrinterLayer Then
            Return CType(oPrinterLayer, CustomPageLayoutMap)
         End If
      Next oPrinterLayer
      Return Nothing
   End Function
   Private Function mGetPrinterPage() As PagePrinterLayer
      Dim oPrinterOverlay As PrinterInteractiveOverLay = mGetPrinterOverlay()
      Dim oPrinterLayer As PrinterLayer
      For Each oPrinterLayer In oPrinterOverlay.PrinterLayers
         If TypeOf oPrinterLayer Is PagePrinterLayer Then
            Return CType(oPrinterLayer, PagePrinterLayer)
         End If
      Next oPrinterLayer
      Return Nothing
   End Function
   Public Sub Print()

      '***** Get the printer for printing
      Dim oPrinterSettings As PrinterSettings = GetPrinter()
      If oPrinterSettings Is Nothing Then
         Return
      End If

      Dim oPrinterOverLay As PrinterInteractiveOverLay = mGetPrinterOverlay()
      Dim oPagePrinterLayer As PagePrinterLayer = mGetPrinterPage()

      Dim oPrintDocument As New PrintDocument()
      With oPrintDocument
         .PrinterSettings = oPrinterSettings
         .DefaultPageSettings.Landscape = True
         If oPagePrinterLayer.Orientation = PrinterOrientation.Portrait Then
            .DefaultPageSettings.Landscape = False
         End If
         .DefaultPageSettings.PaperSize = GetPrintPreviewPaperSize(oPagePrinterLayer)
      End With

      Dim oPrinterCanvas As PrinterGeoCanvas = New PrinterGeoCanvas()

      '***** Create a rectangle to represent the drawing area for the document
      oPrinterCanvas.DrawingArea = mGetPrinterCanvasDrawingArea(oPrintDocument)
      '***** Start the drawing process
      oPrinterCanvas.BeginDrawing(oPrintDocument, oPagePrinterLayer.GetBoundingBox(), PageLayout.MapUnit)

      '***** Loop through all of the PrintingLayers in the PrinterInteractiveOverlay 
      '***** and print all of the except for the PagePrinterLayer                
      Dim labelsInAllLayers As Collection(Of SimpleCandidate) = New Collection(Of SimpleCandidate)()
      For Each oPrinterLayer As PrinterLayer In oPrinterOverLay.PrinterLayers
         oPrinterLayer.IsDrawing = True
         If Not (TypeOf oPrinterLayer Is PagePrinterLayer) Then
            oPrinterLayer.Draw(oPrinterCanvas, labelsInAllLayers)
         End If
         oPrinterLayer.IsDrawing = False
      Next oPrinterLayer

      oPrinterCanvas.EndDrawing()
   End Sub
   Private Function mGetPrinterCanvasDrawingArea(oPrintDocument As PrintDocument) As Rectangle
      Dim oRectangle As Rectangle
      '***** Here we create a System.Drawing.Rectangle to be used as the drawing
      '***** area for the PrinterGeoCanvas that will draw the map on the printer.
      '***** Notice that when the page has been set to Landscape the Width and Height
      '***** must be reversed.
      With oPrintDocument.DefaultPageSettings.PrintableArea()
         If oPrintDocument.DefaultPageSettings.Landscape Then
            oRectangle = New Rectangle(0, 0, Convert.ToInt32(.Height), Convert.ToInt32(.Width))
         Else
            oRectangle = New Rectangle(0, 0, Convert.ToInt32(.Width), Convert.ToInt32(.Height))
         End If
      End With

      Return oRectangle
   End Function

   Public Shared Function GetPrinter() As PrinterSettings
      Dim oPrintDialog As New PrintDialog
      Dim oPrinterSettings As PrinterSettings = Nothing

      With oPrintDialog
         If Not .ShowDialog() = DialogResult.Cancel Then
            oPrinterSettings = .PrinterSettings
         End If
      End With
      Return oPrinterSettings
   End Function
   Private Function GetPrintPreviewPaperSize(ByVal pagePrinterLayer As PagePrinterLayer) As PaperSize
      Dim printPreviewPaperSize As PaperSize = New PaperSize("AnsiA", 850, 1100)
      Select Case pagePrinterLayer.PageSize
         Case PrinterPageSize.AnsiA
            printPreviewPaperSize = New PaperSize("AnsiA", 850, 1100)
         Case PrinterPageSize.AnsiB
            printPreviewPaperSize = New PaperSize("AnsiB", 1100, 1700)
         Case PrinterPageSize.AnsiC
            printPreviewPaperSize = New PaperSize("AnsiC", 1700, 2200)
         Case PrinterPageSize.AnsiD
            printPreviewPaperSize = New PaperSize("AnsiD", 2200, 3400)
         Case PrinterPageSize.AnsiE
            printPreviewPaperSize = New PaperSize("AnsiE", 3400, 4400)
         Case PrinterPageSize.Custom
            printPreviewPaperSize = New PaperSize("Custom Size", CInt(pagePrinterLayer.CustomWidth), CInt(pagePrinterLayer.CustomHeight))
         Case Else
      End Select

      Return printPreviewPaperSize
   End Function

   Private Sub btnPrint_Click(sender As System.Object, e As System.EventArgs) Handles btnPrint.Click
      btnPrint.Enabled = False
      Print()
      btnPrint.Enabled = True
   End Sub

   Public Sub New()

      ' This call is required by the designer.
      InitializeComponent()

      ' Add any initialization after the InitializeComponent() call.

   End Sub
End Class
